@@ -1,4 +1,3 @@
-
 #' @title Prepare GDC data
 #' @description
 #'   Reads the data downloaded and prepare it into an R object
@@ -45,23 +44,27 @@
 #' @importFrom data.table setcolorder setnames
 #' @importFrom GenomicRanges GRanges
 #' @importFrom IRanges IRanges
-GDCprepare <- function(query,
-                       save = FALSE,
-                       save.filename,
-                       directory = "GDCdata",
-                       summarizedExperiment = TRUE,
-                       remove.files.prepared = FALSE,
-                       add.gistic2.mut = NULL,
-                       mut.pipeline = "mutect2",
-                       mutant_variant_classification = c("Frame_Shift_Del",
-                                                         "Frame_Shift_Ins",
-                                                         "Missense_Mutation",
-                                                         "Nonsense_Mutation",
-                                                         "Splice_Site",
-                                                         "In_Frame_Del",
-                                                         "In_Frame_Ins",
-                                                         "Translation_Start_Site",
-                                                         "Nonstop_Mutation")){
+GDCprepare <- function(
+  query,
+  save = FALSE,
+  save.filename,
+  directory = "GDCdata",
+  summarizedExperiment = TRUE,
+  remove.files.prepared = FALSE,
+  add.gistic2.mut = NULL,
+  mut.pipeline = "mutect2",
+  mutant_variant_classification = c(
+    "Frame_Shift_Del",
+    "Frame_Shift_Ins",
+    "Missense_Mutation",
+    "Nonsense_Mutation",
+    "Splice_Site",
+    "In_Frame_Del",
+    "In_Frame_Ins",
+    "Translation_Start_Site",
+    "Nonstop_Mutation"
+  )
+){
 
   isServeOK()
   if(missing(query)) stop("Please set query parameter")
@@ -82,30 +85,35 @@ GDCprepare <- function(query,
     print(knitr::kable(dup))
     stop("There are samples duplicated. We will not be able to prepare it")
   }
-  if(!save & remove.files.prepared) {
+
+  if (!save & remove.files.prepared) {
     stop("To remove the files, please set save to TRUE. Otherwise, the data will be lost")
   }
   # We save the files in project/source/data.category/data.type/file_id/file_name
   source <- ifelse(query$legacy,"legacy","harmonized")
-  files <- file.path(query$results[[1]]$project, source,
-                     gsub(" ","_",query$results[[1]]$data_category),
-                     gsub(" ","_",query$results[[1]]$data_type),
-                     gsub(" ","_",query$results[[1]]$file_id),
-                     gsub(" ","_",query$results[[1]]$file_name))
+  files <- file.path(
+    query$results[[1]]$project, source,
+    gsub(" ","_",query$results[[1]]$data_category),
+    gsub(" ","_",query$results[[1]]$data_type),
+    gsub(" ","_",query$results[[1]]$file_id),
+    gsub(" ","_",query$results[[1]]$file_name)
+  )
 
   files <- file.path(directory, files)
 
   # For IDAT prepare since we need to put all IDATs in the same folder the code below will not work
   # a second run
-  if(!all(file.exists(files))) {
+  if (!all(file.exists(files))) {
     # We have to check we movedthe files
-    if(query$data.category == "Raw microarray data"){
-      files.idat <- file.path(query$results[[1]]$project, source,
-                              gsub(" ","_",query$results[[1]]$data_category),
-                              gsub(" ","_",query$results[[1]]$data_type),
-                              gsub(" ","_",query$results[[1]]$file_name))
+    if (query$data.category == "Raw microarray data"){
+      files.idat <- file.path(
+        query$results[[1]]$project, source,
+        gsub(" ","_",query$results[[1]]$data_category),
+        gsub(" ","_",query$results[[1]]$data_type),
+        gsub(" ","_",query$results[[1]]$file_name)
+      )
       files.idat <- file.path(directory, files.idat)
-      if(!all(file.exists(files) | file.exists(files.idat))) {
+      if (!all(file.exists(files) | file.exists(files.idat))) {
         stop(paste0("I couldn't find all the files from the query. ",
                     "Please check if the directory parameter is right or `GDCdownload` downloaded the samples."))
 
@@ -117,78 +125,94 @@ GDCprepare <- function(query,
   }
 
   cases <- ifelse(grepl("TCGA|TARGET",query$results[[1]]$project %>% unlist()),query$results[[1]]$cases,query$results[[1]]$sample.submitter_id)
-  if(grepl("Transcriptome Profiling", query$data.category, ignore.case = TRUE)){
+  if (grepl("Transcriptome Profiling", query$data.category, ignore.case = TRUE)){
     data <- readTranscriptomeProfiling(files = files,
                                        data.type = ifelse(!is.na(query$data.type),  as.character(query$data.type),  unique(query$results[[1]]$data_type)),
                                        workflow.type = unique(query$results[[1]]$analysis_workflow_type),
                                        cases = cases,
                                        summarizedExperiment)
   } else if(grepl("Copy Number Variation",query$data.category,ignore.case = TRUE)) {
-    if(unique(query$results[[1]]$data_type) == "Gene Level Copy Number Scores") {
+    if (unique(query$results[[1]]$data_type) == "Gene Level Copy Number Scores") {
       data <- readGISTIC(files, query$results[[1]]$cases)
     } else {
       data <- readCopyNumberVariation(files, query$results[[1]]$cases)
     }
-  }  else if(grepl("DNA methylation",query$data.category, ignore.case = TRUE)) {
+  }  else if (grepl("DNA methylation",query$data.category, ignore.case = TRUE)) {
     data <- readDNAmethylation(files, cases = cases, summarizedExperiment, unique(query$platform))
-  }  else if(grepl("Raw intensities",query$data.type, ignore.case = TRUE)) {
+  }  else if (grepl("Raw intensities",query$data.type, ignore.case = TRUE)) {
     # preparing IDAT files
     data <- readIDATDNAmethylation(files, barcode = cases, summarizedExperiment, unique(query$platform), query$legacy)
-  }  else if(grepl("Protein expression",query$data.category,ignore.case = TRUE)) {
+  }  else if (grepl("Protein expression",query$data.category,ignore.case = TRUE)) {
     data <- readProteinExpression(files, cases = cases)
-  }  else if(grepl("Simple Nucleotide Variation",query$data.category,ignore.case = TRUE)) {
+  }  else if (grepl("Simple Nucleotide Variation",query$data.category,ignore.case = TRUE)) {
     if(grepl("Masked Somatic Mutation",query$results[[1]]$data_type,ignore.case = TRUE) | source == "legacy")
       suppressWarnings(data <- readSimpleNucleotideVariationMaf(files))
-  }  else if(grepl("Clinical|Biospecimen", query$data.category, ignore.case = TRUE)){
+  }  else if (grepl("Clinical|Biospecimen", query$data.category, ignore.case = TRUE)){
     data <- readClinical(files, query$data.type, cases = cases)
     summarizedExperiment <- FALSE
   } else if (grepl("Gene expression",query$data.category,ignore.case = TRUE)) {
-    if(query$data.type == "Gene expression quantification")
-      data <- readGeneExpressionQuantification(files = files,
-                                               cases = cases,
-                                               summarizedExperiment = summarizedExperiment,
-                                               genome = ifelse(query$legacy,"hg19","hg38"),
-                                               experimental.strategy = unique(query$results[[1]]$experimental_strategy))
+    if (query$data.type == "Gene expression quantification")
+      data <- readGeneExpressionQuantification(
+        files = files,
+        cases = cases,
+        summarizedExperiment = summarizedExperiment,
+        genome = ifelse(query$legacy,"hg19","hg38"),
+        experimental.strategy = unique(query$results[[1]]$experimental_strategy)
+      )
 
-    if(query$data.type == "miRNA gene quantification")
-      data <- readGeneExpressionQuantification(files = files,
-                                               cases = cases,
-                                               summarizedExperiment = FALSE,
-                                               genome = ifelse(query$legacy,"hg19","hg38"),
-                                               experimental.strategy = unique(query$results[[1]]$experimental_strategy))
-    if(query$data.type == "miRNA isoform quantification")
-      data <- readmiRNAIsoformQuantification(files = files,
-                                             cases = query$results[[1]]$cases)
+    if (query$data.type == "miRNA gene quantification")
+      data <- readGeneExpressionQuantification(
+        files = files,
+        cases = cases,
+        summarizedExperiment = FALSE,
+        genome = ifelse(query$legacy,"hg19","hg38"),
+        experimental.strategy = unique(query$results[[1]]$experimental_strategy)
+      )
 
-    if(query$data.type == "Isoform expression quantification")
+    if (query$data.type == "miRNA isoform quantification")
+      data <- readmiRNAIsoformQuantification(
+        files = files,
+        cases = query$results[[1]]$cases
+      )
+
+    if (query$data.type == "Isoform expression quantification")
       data <- readIsoformExpressionQuantification(files = files, cases = cases)
 
-    if(query$data.type == "Exon quantification")
-      data <- readExonQuantification(files = files,
-                                     cases = cases,
-                                     summarizedExperiment = summarizedExperiment)
+    if (query$data.type == "Exon quantification")
+      data <- readExonQuantification(
+        files = files,
+        cases = cases,
+        summarizedExperiment = summarizedExperiment
+      )
 
   }
   # Add data release to object
-  if(summarizedExperiment & !is.data.frame(data)){
+  if (summarizedExperiment & !is.data.frame(data)) {
     metadata(data) <- list("data_release" = getGDCInfo()$data_release)
   }
 
 
-  if((!is.null(add.gistic2.mut)) & summarizedExperiment) {
+  if ((!is.null(add.gistic2.mut)) & summarizedExperiment) {
     message("=> Adding GISTIC2 and mutation information....")
     genes <- tolower(levels(EAGenes$Gene))
-    if(!all(tolower(add.gistic2.mut) %in% genes)) message(paste("These genes were not found:\n",
-                                                                paste(add.gistic2.mut[! tolower(add.gistic2.mut) %in% genes],collapse = "\n=> ")))
+    if (!all(tolower(add.gistic2.mut) %in% genes)) {
+      message(
+        paste("These genes were not found:\n",
+              paste(add.gistic2.mut[! tolower(add.gistic2.mut) %in% genes],collapse = "\n=> ")
+        )
+      )
+    }
     add.gistic2.mut <- add.gistic2.mut[tolower(add.gistic2.mut) %in% tolower(genes)]
-    if(length(add.gistic2.mut) > 0){
+    if (length(add.gistic2.mut) > 0){
       info <- colData(data)
       for(i in unlist(query$project)){
-        info <- get.mut.gistc.information(info,
-                                          i,
-                                          add.gistic2.mut,
-                                          mut.pipeline = mut.pipeline,
-                                          mutant_variant_classification = mutant_variant_classification)
+        info <- get.mut.gistc.information(
+          info,
+          i,
+          add.gistic2.mut,
+          mut.pipeline = mut.pipeline,
+          mutant_variant_classification = mutant_variant_classification
+        )
       }
       colData(data) <- info
     }
@@ -197,7 +221,7 @@ GDCprepare <- function(query,
     if(any(duplicated(data$sample))) {
       message("Replicates found.")
       if(any(data$is_ffpe)) message("FFPE should be removed. You can modify the data with the following command:\ndata <- data[,!data$is_ffpe]")
-      print(as.data.frame(colData(data)[data$sample %in% data$sample[duplicated(data$sample)],c("is_ffpe"),drop=F]))
+      print(as.data.frame(colData(data)[data$sample %in% data$sample[duplicated(data$sample)],c("is_ffpe"),drop = FALSE]))
     }
   }
 
@@ -335,70 +359,84 @@ readmiRNAIsoformQuantification <- function (files, cases){
 
 }
 readSimpleNucleotideVariationMaf <- function(files){
-  ret <- read_tsv(files,
-                  comment = "#",
-                  col_types = cols(
-                    Entrez_Gene_Id = col_integer(),
-                    Start_Position = col_integer(),
-                    End_Position = col_integer(),
-                    t_depth = col_integer(),
-                    t_ref_count = col_integer(),
-                    t_alt_count = col_integer(),
-                    n_depth = col_integer(),
-                    ALLELE_NUM = col_integer(),
-                    TRANSCRIPT_STRAND = col_integer(),
-                    PICK = col_integer(),
-                    TSL = col_integer(),
-                    HGVS_OFFSET = col_integer(),
-                    MINIMISED = col_integer()),
-                  progress = TRUE)
-  if(ncol(ret) == 1) ret <- read_csv(files,
-                                     comment = "#",
-                                     col_types = cols(
-                                       Entrez_Gene_Id = col_integer(),
-                                       Start_Position = col_integer(),
-                                       End_Position = col_integer(),
-                                       t_depth = col_integer(),
-                                       t_ref_count = col_integer(),
-                                       t_alt_count = col_integer(),
-                                       n_depth = col_integer(),
-                                       ALLELE_NUM = col_integer(),
-                                       TRANSCRIPT_STRAND = col_integer(),
-                                       PICK = col_integer(),
-                                       TSL = col_integer(),
-                                       HGVS_OFFSET = col_integer(),
-                                       MINIMISED = col_integer()),
-                                     progress = TRUE)
+  ret <- read_tsv(
+    files,
+    comment = "#",
+    col_types = cols(
+      Entrez_Gene_Id = col_integer(),
+      Start_Position = col_integer(),
+      End_Position = col_integer(),
+      t_depth = col_integer(),
+      t_ref_count = col_integer(),
+      t_alt_count = col_integer(),
+      n_depth = col_integer(),
+      ALLELE_NUM = col_integer(),
+      TRANSCRIPT_STRAND = col_integer(),
+      PICK = col_integer(),
+      TSL = col_integer(),
+      HGVS_OFFSET = col_integer(),
+      MINIMISED = col_integer()),
+    progress = TRUE
+  )
+
+  if(ncol(ret) == 1) ret <- read_csv(
+    files,
+    comment = "#",
+    col_types = cols(
+      Entrez_Gene_Id = col_integer(),
+      Start_Position = col_integer(),
+      End_Position = col_integer(),
+      t_depth = col_integer(),
+      t_ref_count = col_integer(),
+      t_alt_count = col_integer(),
+      n_depth = col_integer(),
+      ALLELE_NUM = col_integer(),
+      TRANSCRIPT_STRAND = col_integer(),
+      PICK = col_integer(),
+      TSL = col_integer(),
+      HGVS_OFFSET = col_integer(),
+      MINIMISED = col_integer()),
+    progress = TRUE
+  )
   return(ret)
 }
 
 
 #' @importFrom purrr reduce
-readGeneExpressionQuantification <- function(files,
-                                             cases,
-                                             genome = "hg19",
-                                             summarizedExperiment = TRUE,
-                                             experimental.strategy,
-                                             platform){
+readGeneExpressionQuantification <- function(
+  files,
+  cases,
+  genome = "hg19",
+  summarizedExperiment = TRUE,
+  experimental.strategy,
+  platform
+){
   skip <- unique((ifelse(experimental.strategy == "Gene expression array",1,0)))
 
   if(length(skip) > 1) stop("It is not possible to handle those different platforms together")
 
   print.header(paste0("Reading ", length(files)," files"),"subsection")
-  ret <- plyr::alply(seq_along(files),1,.fun = function(i,cases){
-    data <- fread(files[i],
-                  header = TRUE,
-                  sep = "\t",
-                  stringsAsFactors = FALSE,
-                  skip = skip)
-    if(!missing(cases)) {
-      assay.list <<- gsub(" |\\(|\\)|\\/","_",colnames(data)[2:ncol(data)])
-      # We will use this because there might be more than one col for each samples
-      setnames(data,colnames(data)[2:ncol(data)],
-               paste0(gsub(" |\\(|\\)|\\/","_",colnames(data)[2:ncol(data)]),"_",cases[i]))
-    }
-    data
-  },.progress = "time",cases = cases)
+  ret <- plyr::alply(
+    .data = seq_along(files),
+    .margins = 1,
+    .fun = function(i,cases){
+
+      data <- fread(
+        input = files[i],
+        header = TRUE,
+        sep = "\t",
+        stringsAsFactors = FALSE,
+        skip = skip
+      )
+
+      if(!missing(cases)) {
+        assay.list <<- gsub(" |\\(|\\)|\\/","_",colnames(data)[2:ncol(data)])
+        # We will use this because there might be more than one col for each samples
+        setnames(data,colnames(data)[2:ncol(data)],
+                 paste0(gsub(" |\\(|\\)|\\/","_",colnames(data)[2:ncol(data)]),"_",cases[i]))
+      }
+      data
+    },.progress = "time",cases = cases)
 
   print.header(paste0("Merging ", length(files)," files"),"subsection")
   merging.col <- colnames(ret[[1]])[1]
@@ -409,66 +447,91 @@ readGeneExpressionQuantification <- function(files,
   )
 
   if (summarizedExperiment) {
-    df <- makeSEfromGeneExpressionQuantification(df,assay.list, genome = genome)
+    df <- makeSEfromGeneExpressionQuantification(df, assay.list, genome = genome)
   } else {
     rownames(df) <- df$gene_id
     df$gene_id <- NULL
   }
   return(df)
 }
-makeSEfromGeneExpressionQuantification <- function(df, assay.list, genome = "hg19"){
+
+
+makeSEfromGeneExpressionQuantification <- function(
+  df,
+  assay.list,
+  genome = "hg19"
+){
+
+  # Access genome information to create SE
   gene.location <- get.GRCh.bioMart(genome)
-  if(all(grepl("\\|",df[,1]))){
+
+  if(all(grepl("\\|",df[[1]]))){
     aux <- strsplit(df$gene_id,"\\|")
     GeneID <- unlist(lapply(aux,function(x) x[2]))
     df$entrezgene_id <- as.numeric(GeneID)
     gene.location <- gene.location[!duplicated(gene.location$entrezgene_id),]
     df <- merge(df, gene.location, by = "entrezgene_id")
   } else {
-    df$external_gene_name <- as.character(df[,1])
+    df$external_gene_name <- as.character(df[[1]])
     df <- merge(df, gene.location, by = "external_gene_name")
   }
 
 
   if("transcript_id" %in% assay.list){
-    rowRanges <- GRanges(seqnames = paste0("chr", df$chromosome_name),
-                         ranges = IRanges(start = df$start_position,
-                                          end = df$end_position),
-                         strand = df$strand,
-                         gene_id = df$external_gene_name,
-                         entrezgene = df$entrezgene_id,
-                         ensembl_gene_id = df$ensembl_gene_id,
-                         transcript_id = subset(df, select = 5))
+    rowRanges <- GRanges(
+      seqnames = paste0("chr", df$chromosome_name),
+      ranges = IRanges(start = df$start_position,
+                       end = df$end_position),
+      strand = df$strand,
+      gene_id = df$external_gene_name,
+      entrezgene = df$entrezgene_id,
+      ensembl_gene_id = df$ensembl_gene_id,
+      transcript_id = subset(df, select = 5)
+    )
     names(rowRanges) <- as.character(df$gene_id)
     assay.list <- assay.list[which(assay.list != "transcript_id")]
   } else {
-    rowRanges <- GRanges(seqnames = paste0("chr", df$chromosome_name),
-                         ranges = IRanges(start = df$start_position,
-                                          end = df$end_position),
-                         strand = df$strand,
-                         gene_id = df$external_gene_name,
-                         entrezgene = df$entrezgene_id,
-                         ensembl_gene_id = df$ensembl_gene_id)
+    rowRanges <- GRanges(
+      seqnames = paste0("chr", df$chromosome_name),
+      ranges = IRanges(
+        start = df$start_position,
+        end = df$end_position
+      ),
+      strand = df$strand,
+      gene_id = df$external_gene_name,
+      entrezgene = df$entrezgene_id,
+      ensembl_gene_id = df$ensembl_gene_id
+    )
     names(rowRanges) <- as.character(df$external_gene_name)
   }
+
   suppressWarnings({
-    assays <- lapply(assay.list, function (x) {
-      return(data.matrix(subset(df, select = grep(x,colnames(df),ignore.case = TRUE))))
+    assays <- lapply(assay.list, function(x) {
+      return(
+        data.matrix(
+          subset(df, select = grep(x,colnames(df),ignore.case = TRUE))
+        )
+      )
     })
   })
+
   names(assays) <- assay.list
   regex <- paste0("[:alnum:]{4}-[:alnum:]{2}-[:alnum:]{4}",
                   "-[:alnum:]{3}-[:alnum:]{3}-[:alnum:]{4}-[:alnum:]{2}")
   samples <- na.omit(unique(str_match(colnames(df),regex)[,1]))
   colData <-  colDataPrepare(samples)
+
   assays <- lapply(assays, function(x){
     colnames(x) <- NULL
     rownames(x) <- NULL
     return(x)
   })
-  rse <- SummarizedExperiment(assays=assays,
-                              rowRanges=rowRanges,
-                              colData=colData)
+
+  rse <- SummarizedExperiment(
+    assays = assays,
+    rowRanges = rowRanges,
+    colData = colData
+  )
   return(rse)
 }
 
@@ -536,20 +599,19 @@ makeSEfromDNAmethylation <- function(df, probeInfo=NULL){
   rse <- SummarizedExperiment(assays = assay, rowRanges = rowRanges, colData = colData)
 }
 
-readIDATDNAmethylation <- function(files,
-                                   barcode,
-                                   summarizedExperiment,
-                                   platform,
-                                   legacy){
+readIDATDNAmethylation <- function(
+  files,
+  barcode,
+  summarizedExperiment,
+  platform,
+  legacy
+) {
 
-  if (!requireNamespace("sesame", quietly = TRUE)) {
-    stop("sesame package is needed for this function to work. Please install it.",
-         call. = FALSE)
-  }
+  check_package("sesame")
 
   # Check if moved files would be moved outside of scope folder, if so, path doesn't change
   moved.files <- sapply(files,USE.NAMES=FALSE,function(x){
-    if(grepl("Raw_intensities",dirname(dirname(x)))){
+    if (grepl("Raw_intensities",dirname(dirname(x)))) {
       return(file.path(dirname(dirname(x)), basename(x)))
     }
     return(x)
@@ -557,8 +619,14 @@ readIDATDNAmethylation <- function(files,
 
   # for each file move it to upper parent folder if necessary
   plyr::a_ply(files, 1,function(x){
-    if(grepl("Raw_intensities",dirname(dirname(x)))){
-      tryCatch(move(x,file.path(dirname(dirname(x)), basename(x)),keep.copy = FALSE),error = function(e){})
+    if (grepl("Raw_intensities",dirname(dirname(x)))) {
+      tryCatch(
+        move(x,
+             file.path(dirname(dirname(x)), basename(x)),
+             keep.copy = FALSE
+        ),
+        error = function(e){
+        })
     }
   })
 
@@ -571,10 +639,10 @@ readIDATDNAmethylation <- function(files,
   barcode <- unique(data.frame("file" = gsub("_Grn.idat|_Red.idat","",basename(moved.files)), "barcode" = barcode))
   colnames(betas) <- barcode$barcode[match(basename(samples),barcode$file)]
 
-  if(summarizedExperiment){
+  if (summarizedExperiment) {
     met.platform <- "EPIC"
-    if(grepl("450",platform)) met.platform <- "450K"
-    if(grepl("27",platform)) met.platform <- "27K"
+    if (grepl("450",platform)) met.platform <- "450K"
+    if (grepl("27",platform)) met.platform <- "27K"
     betas <- makeSEFromDNAMethylationMatrix(betas,genome = ifelse(legacy,"hg19","hg38"),met.platform = met.platform)
     colData(betas) <- DataFrame(colDataPrepare(colnames(betas)))
   }
@@ -590,17 +658,23 @@ readIDATDNAmethylation <- function(files,
 #' @importFrom GenomicRanges makeGRangesFromDataFrame
 #' @importFrom tibble as_data_frame
 readDNAmethylation <- function(files, cases, summarizedExperiment = TRUE, platform){
-  if(missing(cases)) cases <- NULL
-  if (grepl("OMA00",platform)){
+  if (missing(cases)) cases <- NULL
+  if (grepl("OMA00",platform)) {
     pb <- txtProgressBar(min = 0, max = length(files), style = 3)
     for (i in seq_along(files)) {
-      data <- fread(files[i], header = TRUE, sep = "\t",
-                    stringsAsFactors = FALSE,skip = 1,
-                    na.strings="N/A",
-                    colClasses=c("character", # Composite Element REF
-                                 "numeric"))   # beta value
+      data <- fread(
+        files[i], header = TRUE,
+        sep = "\t",
+        stringsAsFactors = FALSE,
+        skip = 1,
+        na.strings = "N/A",
+        colClasses = c(
+          "character", # Composite Element REF
+          "numeric" # # beta value
+        )
+      )
       setnames(data,gsub(" ", "\\.", colnames(data)))
-      if(!is.null(cases)) setnames(data,2,cases[i])
+      if (!is.null(cases)) setnames(data,2,cases[i])
       if (i == 1) {
         df <- data
       } else {
@@ -614,18 +688,28 @@ readDNAmethylation <- function(files, cases, summarizedExperiment = TRUE, platfo
   } else {
     skip <- ifelse(all(grepl("hg38",files)), 0,1)
     colClasses <- NULL
-    if(!all(grepl("hg38",files))) colClasses <- c("character", # Composite Element REF
-                                                  "numeric",   # beta value
-                                                  "character", # Gene symbol
-                                                  "character", # Chromosome
-                                                  "integer")
+    if (!all(grepl("hg38",files))) {
+      colClasses <- c(
+        "character", # Composite Element REF
+        "numeric",   # beta value
+        "character", # Gene symbol
+        "character", # Chromosome
+        "integer"
+      )
+    }
 
 
     x <- plyr::alply(files,1, function(f) {
-      data <- fread(f, header = TRUE, sep = "\t",
-                    stringsAsFactors = FALSE,skip = skip, colClasses = colClasses)
+      data <- fread(
+        f,
+        header = TRUE,
+        sep = "\t",
+        stringsAsFactors = FALSE,
+        skip = skip,
+        colClasses = colClasses
+      )
       setnames(data,gsub(" ", "\\.", colnames(data)))
-      if(!is.null(cases)) setnames(data,2,cases[which(f == files)])
+      if (!is.null(cases)) setnames(data,2,cases[which(f == files)])
       setcolorder(data,c(1, 3:ncol(data), 2))
     }, .progress = "time")
 
@@ -650,9 +734,10 @@ readDNAmethylation <- function(files, cases, summarizedExperiment = TRUE, platfo
 
 # Barcode example MMRF_1358_1_BM_CD138pos_T1_TSMRU_L02337
 colDataPrepareMMRF <- function(barcode){
-  DataFrame(barcode = barcode,
-            sample = barcode,
-            patient = substr(barcode,1,9)
+  DataFrame(
+    barcode = barcode,
+    sample = barcode,
+    patient = substr(barcode,1,9)
   )
 }
 
@@ -693,55 +778,61 @@ colDataPrepareTARGET <- function(barcode){
                   "-[:alnum:]{3}-[:alnum:]{3}")
   samples <- str_match(barcode,regex)[,1]
 
-  ret <- DataFrame(barcode = barcode,
-                   sample = substr(barcode, 1, 20),
-                   patient = substr(barcode, 1, 16),
-                   tumor.code = substr(barcode, 8, 9),
-                   case.unique.id = substr(barcode, 11, 16),
-                   tissue.code = substr(barcode, 18, 19),
-                   nucleic.acid.code = substr(barcode, 24, 24))
+  ret <- DataFrame(
+    barcode = barcode,
+    sample = substr(barcode, 1, 20),
+    patient = substr(barcode, 1, 16),
+    tumor.code = substr(barcode, 8, 9),
+    case.unique.id = substr(barcode, 11, 16),
+    tissue.code = substr(barcode, 18, 19),
+    nucleic.acid.code = substr(barcode, 24, 24)
+  )
 
   ret <- merge(ret,aux, by = "tissue.code", sort = FALSE)
 
   tumor.code <- c('00','01','02','03','04','10','15','20','21','30','40',
                   '41','50','51','52','60','61','62','63','64','65','70','71','80','81')
 
-  tumor.definition <- c("Non-cancerous tissue", # 00
-                        "Diffuse Large B-Cell Lymphoma (DLBCL)", # 01
-                        "Lung Cancer (all types)", # 02
-                        "Cervical Cancer (all types)", # 03
-                        "Anal Cancer (all types)", # 04
-                        "Acute lymphoblastic leukemia (ALL)", # 10
-                        "Mixed phenotype acute leukemia (MPAL)", # 15
-                        "Acute myeloid leukemia (AML)", # 20
-                        "Induction Failure AML (AML-IF)", # 21
-                        "Neuroblastoma (NBL)", # 30
-                        "Osteosarcoma (OS)",  # 40
-                        "Ewing sarcoma",   # 41
-                        "Wilms tumor (WT)", # 50
-                        "Clear cell sarcoma of the kidney (CCSK)", # 51
-                        "Rhabdoid tumor (kidney) (RT)", # 52
-                        "CNS, ependymoma", # 60
-                        "CNS, glioblastoma (GBM)", # 61
-                        "CNS, rhabdoid tumor", # 62
-                        "CNS, low grade glioma (LGG)", # 63
-                        "CNS, medulloblastoma", # 64
-                        "CNS, other", # 65
-                        "NHL, anaplastic large cell lymphoma", # 70
-                        "NHL, Burkitt lymphoma (BL)", # 71
-                        "Rhabdomyosarcoma", #80
-                        "Soft tissue sarcoma, non-rhabdomyosarcoma") # 81
+  tumor.definition <- c(
+    "Non-cancerous tissue", # 00
+    "Diffuse Large B-Cell Lymphoma (DLBCL)", # 01
+    "Lung Cancer (all types)", # 02
+    "Cervical Cancer (all types)", # 03
+    "Anal Cancer (all types)", # 04
+    "Acute lymphoblastic leukemia (ALL)", # 10
+    "Mixed phenotype acute leukemia (MPAL)", # 15
+    "Acute myeloid leukemia (AML)", # 20
+    "Induction Failure AML (AML-IF)", # 21
+    "Neuroblastoma (NBL)", # 30
+    "Osteosarcoma (OS)",  # 40
+    "Ewing sarcoma",   # 41
+    "Wilms tumor (WT)", # 50
+    "Clear cell sarcoma of the kidney (CCSK)", # 51
+    "Rhabdoid tumor (kidney) (RT)", # 52
+    "CNS, ependymoma", # 60
+    "CNS, glioblastoma (GBM)", # 61
+    "CNS, rhabdoid tumor", # 62
+    "CNS, low grade glioma (LGG)", # 63
+    "CNS, medulloblastoma", # 64
+    "CNS, other", # 65
+    "NHL, anaplastic large cell lymphoma", # 70
+    "NHL, Burkitt lymphoma (BL)", # 71
+    "Rhabdomyosarcoma", #80
+    "Soft tissue sarcoma, non-rhabdomyosarcoma"
+  ) # 81
   aux <- DataFrame(tumor.code = tumor.code,tumor.definition)
   ret <- merge(ret,aux, by = "tumor.code", sort = FALSE)
 
   nucleic.acid.code <- c('D','E','W','X','Y','R','S')
-  nucleic.acid.description <-  c("DNA, unamplified, from the first isolation of a tissue",
-                                 "DNA, unamplified, from the first isolation of a tissue embedded in FFPE",
-                                 "DNA, whole genome amplified by Qiagen (one independent reaction)",
-                                 "DNA, whole genome amplified by Qiagen (a second, separate independent reaction)",
-                                 "DNA, whole genome amplified by Qiagen (pool of 'W' and 'X' aliquots)",
-                                 "RNA, from the first isolation of a tissue",
-                                 "RNA, from the first isolation of a tissue embedded in FFPE")
+  nucleic.acid.description <-  c(
+    "DNA, unamplified, from the first isolation of a tissue",
+    "DNA, unamplified, from the first isolation of a tissue embedded in FFPE",
+    "DNA, whole genome amplified by Qiagen (one independent reaction)",
+    "DNA, whole genome amplified by Qiagen (a second, separate independent reaction)",
+    "DNA, whole genome amplified by Qiagen (pool of 'W' and 'X' aliquots)",
+    "RNA, from the first isolation of a tissue",
+    "RNA, from the first isolation of a tissue embedded in FFPE"
+  )
   aux <- DataFrame(nucleic.acid.code = nucleic.acid.code,nucleic.acid.description)
   ret <- merge(ret,aux, by = "nucleic.acid.code", sort = FALSE)
 
@@ -868,68 +959,6 @@ colDataPrepare <- function(barcode){
   return(ret)
 }
 
-#' @title Get hg19 or hg38 information from biomaRt
-#' @description Get hg19 or hg38 information from biomaRt
-#' @param genome hg38 or hg19
-#' @param as.granges Output as GRanges or data.frame
-#' @importFrom biomaRt getBM useMart listDatasets useEnsembl
-#' @export
-get.GRCh.bioMart <- function(genome = "hg19", as.granges = FALSE) {
-  tries <- 0L
-  msg <- character()
-  while (tries < 3L) {
-    gene.location <- tryCatch({
-      host <- ifelse(genome == "hg19", "grch37.ensembl.org",
-                     "www.ensembl.org")
-      mirror <- list(NULL, "useast", "uswest", "asia")[[tries + 1]]
-
-      ensembl <- tryCatch({
-        message(ifelse(is.null(mirror),
-                       paste0("Accessing ", host, " to get gene information"),
-                       paste0("Accessing ", host," (mirror ", mirror,")")))
-        useEnsembl("ensembl", dataset = "hsapiens_gene_ensembl", host = host, mirror = mirror)
-      }, error = function(e) {
-        message(e)
-        return(NULL)
-      })
-
-      attributes <- c("chromosome_name",
-                      "start_position",
-                      "end_position", "strand",
-                      "ensembl_gene_id",
-                      "entrezgene_id",
-                      "external_gene_name")
-
-      db.datasets <- listDatasets(ensembl)
-      description <- db.datasets[db.datasets$dataset == "hsapiens_gene_ensembl",]$description
-      message(paste0("Downloading genome information (try:", tries,") Using: ", description))
-
-      chrom <- c(1:22, "X", "Y")
-      gene.location <- getBM(attributes = attributes,
-                             filters = c("chromosome_name"),
-                             values = list(chrom), mart = ensembl)
-      gene.location
-    }, error = function(e) {
-      msg <<- conditionMessage(e)
-      tries <<- tries + 1L
-      NULL
-    })
-    if(!is.null(gene.location)) break
-  }
-  if (tries == 3L) stop("failed to get URL after 3 tries:", "\n  error: ", msg)
-
-  if(as.granges) {
-    gene.location$strand[gene.location$strand == 1] <- "+"
-    gene.location$strand[gene.location$strand == -1] <- "-"
-    gene.location$chromosome_name <- paste0("chr",gene.location$chromosome_name)
-    gene.location <- makeGRangesFromDataFrame(gene.location, seqnames.field = "chromosome_name",
-                                              start.field = "start_position",
-                                              end.field = "end_position",
-                                              keep.extra.columns = TRUE) # considering the whole gene no their promoters
-  }
-  return(gene.location)
-}
-
 addSubtypeInfo <- function(ret){
   out <- NULL
   message(" => Adding TCGA molecular information from marker papers")
@@ -941,32 +970,34 @@ addSubtypeInfo <- function(ret){
       ret$sample.aux <- substr(ret$sample,1,15)
 
       tumor <- gsub("TCGA-","",proj)
-      available <- c("ACC",
-                     "BRCA",
-                     "BLCA",
-                     "CESC",
-                     "CHOL",
-                     "COAD",
-                     "ESCA",
-                     "GBM",
-                     "HNSC",
-                     "KICH",
-                     "KIRC",
-                     "KIRP",
-                     "LGG",
-                     "LUAD",
-                     "LUSC",
-                     "PAAD",
-                     "PCPG",
-                     "PRAD",
-                     "READ",
-                     "SKCM",
-                     "SARC",
-                     "STAD",
-                     "THCA",
-                     "UCEC",
-                     "UCS",
-                     "UVM")
+      available <- c(
+        "ACC",
+        "BRCA",
+        "BLCA",
+        "CESC",
+        "CHOL",
+        "COAD",
+        "ESCA",
+        "GBM",
+        "HNSC",
+        "KICH",
+        "KIRC",
+        "KIRP",
+        "LGG",
+        "LUAD",
+        "LUSC",
+        "PAAD",
+        "PCPG",
+        "PRAD",
+        "READ",
+        "SKCM",
+        "SARC",
+        "STAD",
+        "THCA",
+        "UCEC",
+        "UCS",
+        "UVM"
+      )
       if (grepl(paste(c(available,"all"),collapse = "|"),tumor,ignore.case = TRUE)) {
         subtype <- TCGAquery_subtype(tumor)
         colnames(subtype) <- paste0("paper_", colnames(subtype))
@@ -1040,13 +1071,15 @@ makeSEfromTranscriptomeProfilingSTAR <- function(data, cases, assay.list){
   })
 
   # Prepare rowRanges
-  rowRanges <- GRanges(seqnames = paste0("chr", data$chromosome_name),
-                       ranges = IRanges(start = data$start_position,
-                                        end = data$end_position),
-                       strand = data$strand,
-                       ensembl_gene_id = data$ensembl_gene_id,
-                       external_gene_name = data$external_gene_name,
-                       original_ensembl_gene_id = data$`#gene`)
+  rowRanges <- GRanges(
+    seqnames = paste0("chr", data$chromosome_name),
+    ranges = IRanges(start = data$start_position,
+                     end = data$end_position),
+    strand = data$strand,
+    ensembl_gene_id = data$ensembl_gene_id,
+    external_gene_name = data$external_gene_name,
+    original_ensembl_gene_id = data$`#gene`
+  )
   names(rowRanges) <- as.character(data$ensembl_gene_id)
   rse <- SummarizedExperiment(assays = assays,
                               rowRanges = rowRanges,
@@ -1086,17 +1119,21 @@ makeSEfromTranscriptomeProfiling <- function(data, cases, assay.list){
   })
 
   # Prepare rowRanges
-  rowRanges <- GRanges(seqnames = paste0("chr", data$chromosome_name),
-                       ranges = IRanges(start = data$start_position,
-                                        end = data$end_position),
-                       strand = data$strand,
-                       ensembl_gene_id = data$ensembl_gene_id,
-                       external_gene_name = data$external_gene_name,
-                       original_ensembl_gene_id = data$X1)
+  rowRanges <- GRanges(
+    seqnames = paste0("chr", data$chromosome_name),
+    ranges = IRanges(start = data$start_position,
+                     end = data$end_position),
+    strand = data$strand,
+    ensembl_gene_id = data$ensembl_gene_id,
+    external_gene_name = data$external_gene_name,
+    original_ensembl_gene_id = data$X1
+  )
   names(rowRanges) <- as.character(data$ensembl_gene_id)
-  rse <- SummarizedExperiment(assays = assays,
-                              rowRanges = rowRanges,
-                              colData = colData)
+  rse <- SummarizedExperiment(
+    assays = assays,
+    rowRanges = rowRanges,
+    colData = colData
+  )
 
   return(rse)
 }
