@@ -2,10 +2,8 @@
 knitr::opts_chunk$set(dpi = 300)
 knitr::opts_chunk$set(cache=FALSE)
 
-## ---- echo = FALSE,hide=TRUE, message=FALSE,warning=FALSE---------------------
-devtools::load_all(".")
-
-## ----message=FALSE, warning=FALSE, include=FALSE------------------------------
+## ----message = FALSE, warning = FALSE, include = FALSE------------------------
+library(TCGAbiolinks)
 library(SummarizedExperiment)
 library(dplyr)
 library(DT)
