@@ -3,7 +3,7 @@ knitr::opts_chunk$set(dpi = 300)
 knitr::opts_chunk$set(cache = FALSE)
 
 ## ---- echo = FALSE,hide=TRUE, message=FALSE,warning=FALSE---------------------
-devtools::load_all(".")
+library(TCGAbiolinks)
 
 ## ----message=FALSE, warning=FALSE, include=FALSE------------------------------
 library(SummarizedExperiment)
@@ -11,11 +11,13 @@ library(dplyr)
 library(DT)
 
 ## ---- eval = FALSE, message = FALSE, results = "hide"-------------------------
-#  query <- GDCquery(project = "TCGA-GBM",
-#                     data.category = "DNA methylation",
-#                     barcode = c("TCGA-06-0122","TCGA-14-1456"),
-#                     platform = "Illumina Human Methylation 27",
-#                     legacy = TRUE)
+#  query <- GDCquery(
+#    project = "TCGA-GBM",
+#    data.category = "DNA methylation",
+#    barcode = c("TCGA-06-0122","TCGA-14-1456"),
+#    platform = "Illumina Human Methylation 27",
+#    legacy = TRUE
+#  )
 #  GDCdownload(query)
 #  data.hg19 <- GDCprepare(query)
 
